import { computed } from "vue";
import { btnList } from "/@/config/btnList";
import { usePermissionStoreHook } from "../store/modules/permission";

/**
 * 按钮鉴权
 * @param {menuRoute} 权限路由
 */
export function usePermission(menuRoute: string) {
  const { powers } = usePermissionStoreHook();

  const permissions = computed(() => powers.get(menuRoute) || []);

  function hasPermissionWithName(permissionName: string) {
    const permission = btnList.find(({ name }) => permissionName === name);
    const isHas = permissions.value.includes(permission.code);
    return isHas;
  }

  function hasPermissionWithCode(permissionCode: string) {
    console.log(permissions.value);
    const isHas = permissions.value.includes(permissionCode);
    return isHas;
  }

  function hasPermissionWithCodes(permissionCodes: string[]) {
    const isHas = permissions.value.every(p => permissionCodes.includes(p));
    return isHas;
  }

  return {
    permissions,
    hasPermissionWithName,
    hasPermissionWithCode,
    hasPermissionWithCodes
  };
}
