import { h } from "vue";
import { ElImage } from "element-plus";
import { DescriptionColumns } from "/@/components/BasicDescriptions";
import { FormConfig } from "/@/components/PageSearch";
import { createTooltip } from "/@/utils/tooltip";

export const projectFormConfig: FormConfig = {
  labelWidth: "100px",
  formItems: [
    {
      label: "项目名称",
      field: "name",
      type: "input",
      span: 12
    },
    {
      label: "所属平台",
      field: "platform",
      type: "input",
      placeholder: "客户公司名称",
      span: 12
    },
    {
      label: "销售方",
      field: "companyNo",
      type: "input",
      placeholder: "",
      span: 12
    },
    {
      label: "购买方",
      field: "project_name",
      type: "input",
      placeholder: "",
      span: 12
    },
    {
      label: "项目总预算",
      field: "budget_total",
      type: "input",
      placeholder: "",
      span: 8
    },
    {
      label: "要求到货时间",
      field: "arrtime",
      type: "date_picker",
      placeholder: "",
      span: 8
    },
    {
      label: "竞价截止时间",
      field: "endtime",
      type: "date_picker",
      placeholder: "",
      span: 8
    },
    {
      label: "项目用途",
      field: "use_desc",
      type: "input",
      placeholder: "",
      span: 24
    },
    {
      label: "项目要求",
      field: "ladder",
      slot: "ladder",
      span: 24
    }
  ]
};

export const isPlatformGoodColumns: DescriptionColumns = [
  {
    field: "good_name",
    label: "商品名称",
    span: 24,
    render: (good_name, { skuCode }) =>
      createTooltip(good_name, "上线商品编号： " + skuCode, 360)
  },
  {
    field: "good_img",
    label: "商品主图",
    span: 12,
    render: good_img => {
      const previewSrcList = good_img ? good_img.split(",") : [];
      return previewSrcList.map(src =>
        h(ElImage, {
          previewSrcList: [src],
          src,
          previewTeleported: true,
          style: {
            height: "20px",
            width: "20px"
          }
        })
      );
    }
  },
  {
    field: "good_info_img",
    label: "商品详情图",
    span: 12,
    render: good_info_img => {
      return h(ElImage, {
        previewSrcList: [good_info_img],
        src: good_info_img,
        previewTeleported: true,
        style: {
          height: "20px",
          width: "20px"
        }
      });
    }
  },
  {
    field: "company",
    label: "业务企业名称",
    span: 8,
    render: (company, { companyNo }) =>
      createTooltip(company, "业务企业编号: " + companyNo, 360)
  },
  {
    field: "platform_name",
    label: "所属平台",
    span: 8
  },
  {
    field: "brand_name",
    label: "品牌",
    span: 8
  },
  {
    field: "cat_info",
    label: "分类",
    span: 8,
    render(cat_info) {
      return cat_info.map(({ name }) => name).join("_");
    }
  }
];
